import request from '@/utils/request'
import { AxiosPromise } from 'axios'

// apiUrl
const api = {
	pagePendingClaim: '/v1/process-task/page-pending-claim',
	pagePendingApproval: '/v1/process-task/page-pending-approval',
	pageMyReceived: '/v1/process-task/page-my-received',
	pageMyApplication: '/v1/process-task/page-my-application',
	pageApproved: '/v1/process-task/page-approved',
	listHisTask: '/v1/process-task/list-his-task', // todo废弃了
	consentTask: '/v1/process-task/consent', // 审批同意
	rejectionTask: '/v1/process-task/rejection', // 审批拒绝
	reviewTask: '/v1/process-task/comment', // 评论审批
	approvalInfo: '/v1/process-task/approval-info' // 审批详情
}

// 待认领任务分页列表
export function processTaskPagePendingClaimApi(data: any): AxiosPromise {
	return request({
		url: api.pagePendingClaim,
		method: 'post',
		data
	})
}

// 待审批任务分页列表
export function processTaskPagePendingApprovalApi(data: any): AxiosPromise {
	return request({
		url: api.pagePendingApproval,
		method: 'post',
		data
	})
}

// 我收到的任务分页列表
export function processTaskPageMyReceivedApi(data: any): AxiosPromise {
	return request({
		url: api.pageMyReceived,
		method: 'post',
		data
	})
}

// 我的申请任务分页列表
export function processTaskPageMyApplicationApi(data: any): AxiosPromise {
	return request({
		url: api.pageMyApplication,
		method: 'post',
		data
	})
}

// 已审批任务分页列表
export function processTaskPageApprovedApi(data: any): AxiosPromise {
	return request({
		url: api.pageApproved,
		method: 'post',
		data
	})
}

// todo废弃了
export function processTaskListHisTaskApi(instanceId: string): AxiosPromise {
	return request({
		url: `${api.listHisTask}/${instanceId}`,
		method: 'post'
	})
}

// 审批同意
export function processConsentTaskApi(data: any): AxiosPromise {
	return request({
		url: api.consentTask,
		method: 'post',
		data
	})
}

// 审批拒绝
export function processRejectionTaskApi(data: any): AxiosPromise {
	return request({
		url: api.rejectionTask,
		method: 'post',
		data
	})
}

// 评论审批
export function processReviewTaskApi(data: any): AxiosPromise {
	return request({
		url: api.reviewTask,
		method: 'post',
		data
	})
}

// 审批详情
export function processApprovalInfoApi(taskId: string): AxiosPromise {
	return request({
		url: `${api.approvalInfo}-${taskId}`,
		method: 'post'
	})
}

// 查看审批信息
export function processTaskApprovalInfo(taskId: string): AxiosPromise {
	return request({
		url: `/v1/process-task/approval-info-${taskId}`,
		method: 'post'
	})
}

export default {
	processTaskPageMyApplicationApi,
	processTaskPageApprovedApi,
	processTaskListHisTaskApi,
	processConsentTaskApi,
	processRejectionTaskApi,
	processReviewTaskApi,
	processApprovalInfoApi,
	processTaskApprovalInfo
}
